/* italic-field-name.css: */
/* Alternative style for Docutils field-lists */

/* :Copyright: © 2023 Günter Milde. */
/* :License: Released under the terms of the `2-Clause BSD license`_,      */
/*    in short:                                                            */
/*                                                                         */
/*    Copying and distribution of this file, with or without modification, */
/*    are permitted in any medium without royalty provided the copyright   */
/*    notice and this notice are preserved.                                */
/*                                                                         */
/*    This file is offered as-is, without any warranty.                    */
/*                                                                         */
/* .. _2-Clause BSD license: http://www.spdx.org/licenses/BSD-2-Clause     */

/* In many contexts, a **bold** field name is too heavy styling. */
/* Use *italic* instead:: */

dl.field-list > dt {
  font-weight: normal;
  font-style: italic;
}
dl.field-list > dt > .colon {
  font-style: normal;
  padding-left: 0.05ex;
}
